@@ -1,5 +1,5 @@
 Ext.define('Ux.locale.override.extjs.ComboBox', {
-    override : 'Ext.form.ComboBox',
+    override : 'Ext.form.field.ComboBox',
 
     requires : [
         'Ux.locale.override.extjs.Component'
@@ -35,4 +35,4 @@ Ext.define('Ux.locale.override.extjs.ComboBox', {
 
         return this;
     }
-});
\ No newline at end of file
+});
